aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/google/protobuf/reflection_ops.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/google/protobuf/reflection_ops.cc')
-rw-r--r--src/google/protobuf/reflection_ops.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/google/protobuf/reflection_ops.cc b/src/google/protobuf/reflection_ops.cc
index eb2a0e7a..3cd50340 100644
--- a/src/google/protobuf/reflection_ops.cc
+++ b/src/google/protobuf/reflection_ops.cc
@@ -50,10 +50,10 @@ namespace internal {
static const Reflection* GetReflectionOrDie(const Message& m) {
const Reflection* r = m.GetReflection();
- if (r == NULL) {
+ if (r == nullptr) {
const Descriptor* d = m.GetDescriptor();
const string& mtype = d ? d->name() : "unknown";
// RawMessage is one known type for which GetReflection() returns NULL.
GOOGLE_LOG(FATAL) << "Message does not support reflection (type " << mtype << ").";
}
return r;
@@ -50,10 +50,10 @@ namespace internal {
const Descriptor* d = m.GetDescriptor();
const string& mtype = d ? d->name() : "unknown";
- // RawMessage is one known type for which GetReflection() returns NULL.
+ // RawMessage is one known type for which GetReflection() returns nullptr.
GOOGLE_LOG(FATAL) << "Message does not support reflection (type " << mtype << ").";
}